@@ -1,6 +1,6 @@
 import django_tables2 as tables
 from netbox.tables import NetBoxTable, columns
-from .models import PTUEvent, PTUEventRelation, PTUEventAssignment, PTAppSystem, PTAppSystemAssignment, PTWorkstation, PTUser
+from .models import PTUEvent, PTUEventRelation, PTUEventAssignment, PTAppSystem, PTAppSystemAssignment, PTWorkstations, PTUsers
 
 
 class PTUEventTable(NetBoxTable):
@@ -77,7 +77,7 @@ class PTUsersTable(NetBoxTable):
     )
 
     class Meta(NetBoxTable.Meta):
-        model = PTUser
+        model = PTUsers
         fields = ('pk', 'name', 'sAMAccountName',
                   'status',
                   'firstname',
@@ -93,6 +93,6 @@ class PTWorkstationsTable(NetBoxTable):
     name = tables.Column(linkify=True)
 
     class Meta(NetBoxTable.Meta):
-        model = PTWorkstation
+        model = PTWorkstations
         fields = ('pk', 'name', 'CN', 'DistinguishedName', 'ad_description', 'description')
         default_columns = ('name', 'CN', 'DistinguishedName', 'ad_description', 'description')
